@@ -4,9 +4,9 @@ from typing import NamedTuple
 __all__ = ["version", "version_info", "version_js", "version_info_js"]
 
 
-version = "3.1.1"
+version = "3.2.2"
 
-version_js = "15.0.0"
+version_js = "16.4.0"
 
 
 _re_version = re.compile(r"(\d+)\.(\d+)\.(\d+)(\D*)(\d*)")
@@ -36,11 +36,14 @@ class VersionInfo(NamedTuple):
         serial = int(serial) if serial else 0
         return cls(major, minor, micro, level, serial)
 
-    def __str__(self):
+    def __str__(self) -> str:
         v = f"{self.major}.{self.minor}.{self.micro}"
         level = self.releaselevel
         if level and level != "final":
-            v = f"{v}{level[:1]}{self.serial}"
+            level = level[:1]
+            if level == "c":
+                level = "rc"
+            v = f"{v}{level}{self.serial}"
         return v
 
 
